﻿clear;

# variables
$serverName = "(LocalDb)\MSSQLLocalDB"
$masterDatabase = "master"
$testDatabaseName = "TestDB"


$createDatabaseScriptsFolder = "D:\Demo\ScriptsFolder\CreateDatabase\"
$migrationScriptsFolder = "D:\Demo\ScriptsFolder\"


$unitTestsFolder = "D:\Demo\UnitTests\"


$importDataFileName = "D:\Demo\TestData\CSV\sample_data.csv"
$importTemplateFileName = "D:\Demo\TestData\CSV\template.dit"

$generatorFile = "D:\Demo\TestData\TestDB(MSSQLLocalDB).dgen"


$testReportOutputFileName = "D:\Demo\TestReport\report.xml"


$publishFileName = "Test.DevOpsAutomation.Database"
$outputFolder = "D:\Demo\Project\"


Function check {
    param($result)

    if ($result) {
        Write-Host "Success" -ForegroundColor Green; Write-host ""
    }
    else {
        Write-Host "Failed" -ForegroundColor Red;
        Exit(1)
    }
}


#region Create TestDB

    # Create master database connection
    Write-Host "Creating master database connection...`r`n"
    $masterConnection = New-DevartSqlDatabaseConnection -Server $serverName -Database $masterDatabase -WindowsAuthentication $true

    # Test master database connection
    Write-Host "Testing database connection...`r`n"
    $result = Test-DevartDatabaseConnection -Connection $masterConnection;
    check($result)


    # Recreating test database
    Write-Host "Recreating database..."
    $result = Invoke-DevartExecuteScript -Input $createDatabaseScriptsFolder -Connection $masterConnection
    check($result)

#endregion


#region Run the migration scripts against the TestDB database

    # Create TestDB database connection
    Write-Host "Creating TestDB database connection...`r`n"
    $testDBConnection = New-DevartSqlDatabaseConnection -Server $serverName -Database $testDatabaseName -WindowsAuthentication $true

    # Test TestDB database connection
    Write-Host "Testing TestDB database connection...`r`n"
    $result = Test-DevartDatabaseConnection -Connection $testDBConnection;
    check($result)


    # Run the migration scripts against TestDB database
    Write-Host "Run migration scripts..."
    $result = Invoke-DevartExecuteScript -Input $migrationScriptsFolder -Connection $testDBConnection
    check($result)

#endregion


# Restore unit tests on the database

Write-Host "Restoring unit tests..."
$result = Invoke-DevartExecuteScript -Input $unitTestsFolder -Connection $testDBConnection
check($result)

#endregion



#region Import sample data from a file to certain table

Write-Host "Importing sample data from a file...`r`n"
$result = Invoke-DevartDataImport -InputFile $importDataFileName -TemplateFile $importTemplateFileName
check($result)

#endregion


#region Fill database with sample data and run unit tests

Write-Host "Filling database with sample data and running unit tests..."
$result = Invoke-DevartDatabaseTests -InputObject $testDBConnection -InstalltSQLtFramework -IncludeTestData -DataGeneratorProject $generatorFile -OutReportFileName $testReportOutputFileName -ReportFormat JUnit -RewriteReport
check($result)

#endregion


# region Export zip package

Write-Host "Exporting a database project..."
$project= New-DevartDatabaseProject $migrationScriptsFolder
Set-DevartPackageInfo -Project $project -Id $publishFileName -Version 3.0.0
$result = Export-DevartDatabaseProject -Project $project -Format Zip -OutputDirectory $outputFolder -Overwrite
check($result)

#endregion